import React, { Component } from 'react';
import { StyleSheet, View, TouchableHighlight, Text } from 'react-native';
import PropTypes from 'prop-types';
import * as Animatable from 'react-native-animatable';

export default class RNAC extends Component {
  handleLeftButtonRef = ref => this.leftButton = ref;
  handleRightButtonRef = ref => this.rightButton = ref;
  handleCountViewRef = ref => this.countView = ref;
  constructor(props) {
    super(props);
    this.state = {
      count: props.defaultCount,
    };
  }

  clickLeft = () => {
    if (this.state.count !== '+') {
      this.props.onChangeCount(this.state.count + 1);
      this.setState({
        count: this.state.count + 1,
      })
      this.leftButton.tada(500).then(endState => console.log(endState.finished ? 'bounce finished' : 'bounce cancelled'))
      this.countView.bounce(500).then(endState => console.log(endState.finished ? 'bounce finished' : 'bounce cancelled'))  
    }
  };
  clickRight = () => {
    if(this.state.count === 1 && this.state.count !== '+') {
      this.leftButton.fadeOutRight(500).then(endState => console.log(endState.finished ? 'bounce finished' : 'bounce cancelled'))
      this.rightButton.fadeOutLeft(500).then(endState => console.log(endState.finished ? 'bounce finished' : 'bounce cancelled'))    
      this.props.onChangeCount(0);
      this.setState({
        count: '+',
      })
    }
    else if(this.state.count > 0 && this.state.count !== '+') {
      this.rightButton.tada(500).then(endState => console.log(endState.finished ? 'bounce finished' : 'bounce cancelled'))
      this.countView.bounce(500).then(endState => console.log(endState.finished ? 'bounce finished' : 'bounce cancelled'))
      this.props.onChangeCount(this.state.count - 1);
      this.setState({
        count: this.state.count - 1,
      });
    }
        
  };
  clickOnlyOne = () => {
    if(this.state.count === '+') {
      this.props.onChangeCount(1);
      this.rightButton.fadeInLeft(500).then(endState => console.log(endState.finished ? 'bounce finished' : 'bounce cancelled'))
      this.leftButton.fadeInRight(500).then(endState => console.log(endState.finished ? 'bounce finished' : 'bounce cancelled'))    
      this.setState({
        count: 1,
      })
    }
  }
  render() {
    const height = this.props.height;
    const fontSize = height * 50 / 90;
    return (
      <View style={[styles.container, { 
        height: height,
        width:height * 2.3,
        flexDirection: 'row',
        }]}>
        <TouchableHighlight
          underlayColor="transparent"
          style={{
            height: height * 0.766,
            width: height * 0.766,
            marginTop: 6,
          }}
          onPress= {this.clickLeft}
        >
          <Animatable.View 
            ref={this.handleLeftButtonRef}
            style={{
              flex:1,
              backgroundColor:'brown',
              borderRadius: height,
              justifyContent: 'center',
              alignItems: 'center'}
            }
          >
            <Text style={{fontSize: fontSize}} >
              +
            </Text>
          </Animatable.View>
        </TouchableHighlight>
        <TouchableHighlight
          underlayColor="transparent"
          style={{
            height: height * 0.766,
            width: height * 0.766 * (this.state.count > 9 ? (this.state.count > 99 ? 2 : 1.5) : 1),
          }}
          onPress= {this.clickOnlyOne}
        >
          <Animatable.View
            ref={this.handleCountViewRef}
            style={{
              backgroundColor: 'green',
              height: height * 0.766,
              width: height * 0.766 * (this.state.count > 9 ? (this.state.count > 99 ? 2 : 1.5) : 1),
              borderRadius: height,
              marginTop: 6,
              flex: 1,
              justifyContent: 'center',
              alignItems: 'center'
            }}
          >
            <Text style={{fontSize: fontSize}} >
              {this.state.count}
            </Text>
          </Animatable.View>
        </TouchableHighlight>

        <TouchableHighlight
          underlayColor="transparent"
          style={{
            height: height * 0.766,
            width: height * 0.766,
            marginTop: 6,
          }}
          onPress= {this.clickRight}
        >
          <Animatable.View 
            ref={this.handleRightButtonRef}
            style={{
              flex:1,
              backgroundColor:'brown',
              borderRadius: height,
              justifyContent: 'center',
              alignItems: 'center'
            }}
          >
            <Text style={{fontSize: fontSize}} >
              -
            </Text>
          </Animatable.View>
        </TouchableHighlight>
        
      </View>
    );
  }
}

const styles = StyleSheet.create({
    container: {
    }
});

RNAC.propTypes = {
  height: PropTypes.number,
  maxCount: PropTypes.number,
  defaultCount: PropTypes.number,
  onChangeCount: PropTypes.func,
};

RNAC.defaultProps = {
  height: 100,
  maxCount: 100,
  defaultCount: 1,
  onChangeCount: () => {},
};